Name:           osc
Epoch:          1
Version:        1.15.1
Release:        1%{?dist}.1
Group:          Development/Tools
License:        GPLv2+
Url:            https://github.com/openSUSE/osc
Source:         https://github.com/openSUSE/%{name}/archive/%{version}/%{name}-%{version}.tar.gz
Patch0:         osc-support-osc-copyprj-in-api.patch
Patch1:         osc-add-sb2install-support.patch
Summary:        The openSUSE Build Service Commander
BuildArch:      noarch

BuildRequires:  python3-devel
BuildRequires:  python3dist(setuptools)
BuildRequires:  python3dist(rpm)
BuildRequires:  python3dist(cryptography)
BuildRequires:  python3dist(progressbar2)
BuildRequires:  python3dist(urllib3)
BuildRequires:  python3dist(distro)
BuildRequires:  python3dist(ruamel-yaml)
BuildRequires:  python3dist(sphinx)
BuildRequires:  diffstat
BuildRequires:  argparse-manpage
Requires:       python3dist(rpm)
Requires:       python3dist(cryptography)
Requires:       python3dist(progressbar2)
Requires:       python3dist(urllib3)
Requires:       python3dist(distro)
Requires:       python3dist(ruamel-yaml)
Requires:       python3dist(argcomplete)
Requires:       diffstat

Recommends:     osc-source_validator

%description
Commandline client for the openSUSE Build Service.

See http://en.opensuse.org/openSUSE:OSC , as well as
http://en.opensuse.org/openSUSE:Build_Service_Tutorial for a general
introduction.


%prep
%autosetup -p1
# Version is not right when forming a release at Github
sed -i 's/\(^ *version = \)"[^"]*"$/\1"%{version}"/' osc/util/git_version.py

%build
%py3_build

# build man page
PYTHONPATH=. argparse-manpage \
    --output=osc.1 \
    --format=single-commands-section \
    --module=osc.commandline \
    --function=argparse_manpage_get_parser \
    --project-name=osc \
    --prog=osc \
    --description="Command-line client for Open Build Service" \
    --author="Contributors to the osc project. See the project's GIT history for the complete list." \
    --url="https://github.com/openSUSE/osc/"

PYTHONPATH=. argparse-manpage \
    --output=git-obs.1 \
    --format=single-commands-section \
    --module=osc.commandline_git \
    --function=argparse_manpage_get_parser \
    --project-name=osc \
    --prog=git-obs \
    --description="Git based command-line client for Open Build Service" \
    --author="Contributors to the osc project. See the project's GIT history for the complete list." \
    --url="https://github.com/openSUSE/osc/"

sphinx-build -b man doc .

%install
%py3_install
install -d %{buildroot}%{_localstatedir}/lib/osc-plugins

# install completions for osc
install -Dm0755 contrib/osc.complete %{buildroot}%{_datadir}/osc/complete
install -Dm0644 contrib/complete.csh %{buildroot}%{_sysconfdir}/profile.d/osc.csh
install -Dm0644 contrib/complete.sh %{buildroot}%{_datadir}/bash-completion/completions/osc
install -Dm0644 contrib/osc.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/osc.fish
install -Dm0644 contrib/osc.zsh %{buildroot}%{_datadir}/zsh/functions/Completion/osc.zsh

# install completions for git-obs
install -Dm0644 contrib/git-obs-complete.bash %{buildroot}%{_datadir}/bash-completion/completions/git-obs.bash
install -Dm0644 contrib/git-obs-complete.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/git-obs.fish
install -Dm0644 contrib/git-obs-complete.zsh %{buildroot}%{_datadir}/zsh/functions/Completion/git-obs.zsh

# install man page
install -Dm0644 git-obs-quickstart.1 %{buildroot}%{_mandir}/man1/git-obs-quickstart.1
install -Dm0644 osc.1 %{buildroot}%{_mandir}/man1/osc.1
install -Dm0644 git-obs.1 %{buildroot}%{_mandir}/man1/git-obs.1
install -Dm0644 oscrc.5 %{buildroot}%{_mandir}/man5/oscrc.5

%check
%{__python3} -m unittest

%files
%doc AUTHORS README.md NEWS
%license COPYING

%{_bindir}/osc*
%{_bindir}/git-obs

%{python3_sitelib}/osc*

%dir %{_datadir}/osc
%{_datadir}/osc/complete
%{_datadir}/bash-completion/completions/git-obs.bash
%{_datadir}/bash-completion/completions/osc
%config %{_sysconfdir}/profile.d/osc.csh
%{_datadir}/fish/vendor_completions.d/git-obs.fish
%{_datadir}/fish/vendor_completions.d/osc.fish
%{_datadir}/zsh/functions/Completion/git-obs.zsh
%{_datadir}/zsh/functions/Completion/osc.zsh

%{_mandir}/man*/git-obs*
%{_mandir}/man*/osc*

%dir %{_localstatedir}/lib/osc-plugins
%changelog
* Fri Apr 11 2025 Oleg Girko <ol@infoserver.lv> 1.15.1-1
- rebase to 1.15.1
* Sat Mar 29 2025 Oleg Girko <ol@infoserver.lv> 1.14.0-1
- rebase to 1.14.0
- build docs
- install more completions
- install all generated manuals
- use unittest module for tests
* Tue Sep 24 2024 Oleg Girko <ol@infoserver.lv> 1.9.2-1
- rebase to 1.9.2
* Thu Aug 29 2024 Oleg Girko <ol@infoserver.lv> 1.9.1-1
- rebase to 1.9.1
* Sun Jul 14 2024 Oleg Girko <ol@infoserver.lv> 1.8.3-1
- rebase to 1.8.3
* Sat Jul  6 2024 Oleg Girko <ol@infoserver.lv> 1.8.2-1
- rebase to 1.8.2
* Sun May 26 2024 Oleg Girko <ol@infoserver.lv> 1.7.0-1
- rebase to 1.7.0
* Mon Apr 15 2024 Oleg Girko <ol@infoserver.lv> 1.6.2-1
- rebase to 1.6.2
* Tue Feb 27 2024 Oleg Girko <ol@infoserver.lv> 1.6.1-1
- rebase to 1.6.1
* Tue Jan 30 2024 Oleg Girko <ol@infoserver.lv> 1.6.0-1
- rebase to 1.6.0
* Sat Dec  9 2023 Oleg Girko <ol@infoserver.lv> 1.5.1-1
- rebase to 1.5.1
* Fri Nov 24 2023 Oleg Girko <ol@infoserver.lv> 1.5.0-1
- rebase to 1.5.0
* Thu Nov  2 2023 Oleg Girko <ol@infoserver.lv> 1.4.4-1
- rebase to 1.4.4
* Mon Oct 23 2023 Oleg Girko <ol@infoserver.lv> 1.4.3-1
- rebase to 1.4.3
* Mon Oct 16 2023 Oleg Girko <ol@infoserver.lv> 1.4.2-1
- rebase to 1.4.2
* Fri Oct 13 2023 Oleg Girko <ol@infoserver.lv> 1.4.1-1
- rebase to 1.4.1
* Fri Oct  6 2023 Oleg Girko <ol@infoserver.lv> 1.4.0-1
- rebase to 1.4.0
* Sun Sep  3 2023 Oleg Girko <ol@infoserver.lv> 1.3.1-1
- rebase to 1.3.1
* Tue Aug 15 2023 Oleg Girko <ol@infoserver.lv> 1.3.0-1
- rebase to 1.3.0
* Fri Jul 14 2023 Oleg Girko <ol@infoserver.lv> 1.2.0-1
- rebase to 1.2.0
* Mon May 29 2023 Oleg Girko <ol@infoserver.lv> 1.1.4-1
- rebase to 1.1.4
* Tue May 16 2023 Oleg Girko <ol@infoserver.lv> 1.1.3-1
- rebase to 1.1.3
* Wed May  3 2023 Oleg Girko <ol@infoserver.lv> 1.1.2-1
- rebase to 1.1.2
* Sat Apr 15 2023 Oleg Girko <ol@infoserver.lv> 1.1.1-1
- rebase to 1.1.1
* Fri Mar 24 2023 Oleg Girko <ol@infoserver.lv> 1.0.1-1
- rebase to 1.0.1
* Thu Nov 17 2022 Oleg Girko <ol@infoserver.lv> 0.182.0-3
- add patch fixing Python 3.11 compatibility
* Wed Oct 12 2022 Oleg Girko <ol@infoserver.lv> 0.182.0-2
- add patch to add buid option to load extra dependencies from file
- use %%autosetup in %%prep section
* Thu Sep 15 2022 Oleg Girko <ol@infoserver.lv> 0.182.0-1
- rebase to 0.182.0
* Mon Aug  1 2022 Oleg Girko <ol@infoserver.lv> 0.181.0-1
- rebase to 0.181.0
* Sun Jun 26 2022 Oleg Girko <ol@infoserver.lv> 0.180.0-1
- rebase to 0.180.0
* Mon Jun  6 2022 Oleg Girko <ol@infoserver.lv> 0.179.0-1
- rebase to 0.179.0
* Tue Apr 26 2022 Oleg Girko <ol@infoserver.lv> 0.177.0-1
- rebase to 0.177.0
* Fri Mar 18 2022 Oleg Girko <ol@infoserver.lv> 0.176.0-1
- rebase to 0.176.0
* Fri Nov  5 2021 Oleg Girko <ol@infoserver.lv> 0.175.0-1
- rebase to 0.175.0
* Sat Oct 23 2021 Oleg Girko <ol@infoserver.lv> 0.174.0-3
- require setuptools for build (not pulled by python3-devel in Fedora 35)
* Wed Aug 25 2021 Oleg Girko <ol@infoserver.lv> 0.174.0-2
- add patch to fix XPath in search requests
* Sun Aug  1 2021 Oleg Girko <ol@infoserver.lv> 0.174.0-1
- rebase to 0.174.0
* Wed May 19 2021 Oleg Girko <ol@infoserver.lv> 0.173.0-1
- rebase to 0.173.0
* Mon Feb  1 2021 Oleg Girko <ol@infoserver.lv> 0.172.0-1
- rebase to 0.172.0
* Wed Nov 11 2020 Oleg Girko <ol@infoserver.lv> 0.171.0-1
- rebase to 0.171.0
* Thu Jul  9 2020 Oleg Girko <ol@infoserver.lv> 0.170.0-1
- rebase to 0.170.0
- re-enable tests with Python 3.8 (testsuite fixed)
* Fri May 29 2020 Oleg Girko <ol@infoserver.lv> 0.169.1-1
- rebase to 0.169.1
* Wed May 27 2020 Oleg Girko <ol@infoserver.lv> 0.169.0-1
- rebase to 0.169.0
- disable tests with Python 3.8 for now (testsuite broken)
* Fri Mar 13 2020 Oleg Girko <ol@infoserver.lv> 0.168.2-1
- rebase to 0.168.2
* Wed Mar 11 2020 Oleg Girko <ol@infoserver.lv> 0.168.1-1
- rebase to 0.168.1
* Wed Mar  4 2020 Oleg Girko <ol@infoserver.lv> 0.168.0-1
- rebase to 0.168.0
* Tue Jan  7 2020 Oleg Girko <ol@infoserver.lv> 0.167.2-1
- rebase to 0.167.2
* Tue Dec 10 2019 Oleg Girko <ol@infoserver.lv> 0.167.1-1
- rebase to 0.167.1
* Thu Dec  5 2019 Oleg Girko <ol@infoserver.lv> 0.167.0-1
- rebase to 0.167.0
* Wed Nov 13 2019 Oleg Girko <ol@infoserver.lv> 0.166.2-1
- rebase to 0.166.2
- add patch to support nspawn vm type
* Fri Nov  1 2019 Oleg Girko <ol@infoserver.lv> 0.166.1-1
- rebase to 0.166.1
* Thu Oct 24 2019 Oleg Girko <ol@infoserver.lv> 0.166.0-1
- rebase to 0.166.0
* Mon Aug  5 2019 Oleg Girko <ol@infoserver.lv> 0.165.4-1
- rebase to 0.165.4
* Thu Jul 25 2019 Oleg Girko <ol@infoserver.lv> 0.165.3-1
- rebase to 0.165.3
* Tue Jul  9 2019 Oleg Girko <ol@infoserver.lv> 0.165.2-1
- rebase to 0.165.2
* Mon May 27 2019 Oleg Girko <ol@infoserver.lv> 0.165.1-1
- rebase to 0.165.1
* Sun Apr 28 2019 Oleg Girko <ol@infoserver.lv> 0.165.0-1
- rebase to 0.165.0
- switch to Python 3
* Tue Feb 12 2019 Oleg Girko <ol@infoserver.lv> 0.164.2-1
- rebase to 0.164.2
* Wed Jan 16 2019 Oleg Girko <ol@infoserver.lv> 0.164.1-1
- rebase to 0.164.1
* Thu Jan 10 2019 Oleg Girko <ol@infoserver.lv> 0.164.0-2
- require python2-progressbar
* Wed Jan  9 2019 Oleg Girko <ol@infoserver.lv> 0.164.0-1
- rebase to 0.164.0
- require some packages by their modern names
* Fri Nov 23 2018 Oleg Girko <ol@infoserver.lv> 0.163.0-2
- use python2_sitelib macro instead of python_sitelib
* Mon Aug 20 2018 Oleg Girko <ol@infoserver.lv> 0.163.0-1
- rebase to 0.163.0
* Thu May 31 2018 Oleg Girko <ol@infoserver.lv> 0.162.1-3
- require python-fuse instead of deprecated fuse-python
- use python2 instead of deprecated python for build, install, check
* Tue Dec  5 2017 Oleg Girko <ol@infoserver.lv> 0.162.1-2
- Set epoch to 1 to prevent being replaced by version from Fedora
* Tue Dec  5 2017 Oleg Girko <ol@infoserver.lv> 0.162.1-1
- rebase to 0.162.1
* Tue Nov 28 2017 Oleg Girko <ol@infoserver.lv> 0.162.0-1
- rebase to 0.162.0
* Thu Oct 26 2017 Oleg Girko <ol@infoserver.lv> 0.161.1-1
- rebase to 0.161.1
* Fri Oct  6 2017 Oleg Girko <ol@infoserver.lv> 0.160.0-1
- rebase to 0.160.0
* Tue Mar 21 2017 Oleg Girko <ol@infoserver.lv> 0.157.2-1
- rebase to 0.157.2
* Wed Mar  8 2017 Oleg Girko <ol@infoserver.lv> 0.157.1-1
- rebase to 0.157.1
* Mon Dec 21 2015 Oleg Girko <ol@infoserver.lv> 0.156.0-1
- rebase to 0.156.0
* Tue Sep 15 2015 Oleg Girko <ol@infoserver.lv> 0.155.1-1
- rebase to 0.155.1
* Tue Aug 18 2015 Oleg Girko <ol@infoserver.lv> 0.155.0-1
- rebase to 0.155.0
* Thu May 14 2015 Oleg Girko <ol@infoserver.lv> 0.151.2-3
- fix updated patch to fix for handling API URLs with non-root path
- add %%check section that runs testsuite
* Thu May 14 2015 Oleg Girko <ol@infoserver.lv> 0.151.2-2
- update patch to fix for handling API URLs with non-root path
* Sat Apr 25 2015 Oleg Girko <ol@infoserver.lv> 0.151.2-1
- rebase to 0.151.2
- install completion related scripts to more proper directories
- minor specfile changes to look closer to Fedora version
* Thu Jan  8 2015 Oleg Girko <ol@infoserver.lv> 0.149.0-1
- rebase to 0.149.0
- add full Github download URL to Source
- install completion related scripts to proper directories
* Sun Feb  9 2014 Oleg Girko <ol@infoserver.lv> 0.142.0-5
- add patch to fix "osc build $repo aarch64"
* Thu Feb  6 2014 Oleg Girko <ol@infoserver.lv> 0.142.0-4
- add patch for sb2install support in osc build
* Fri Dec 27 2013 Oleg Girko <ol@infoserver.lv> 0.142.0-3
- fix patch to support 'osc copyprj' in api by Islam Amer
* Fri Dec 13 2013 Oleg Girko <ol@infoserver.lv> 0.142.0-2
- add patch to support 'osc copyprj' in api by Islam Amer
* Tue Nov 26 2013 Oleg Girko <ol@infoserver.lv> 0.142.0-1
- rebase to 0.142.0
* Sat Oct 26 2013 Oleg Girko <ol@infoserver.lv> 0.141.0-2
- fix to support TLS SNI
* Sat Oct 26 2013 Oleg Girko <ol@infoserver.lv> 0.141.0-1
- rebase to 0.141.0
* Fri Jul 26 2013 Oleg Girko <ol@infoserver.lv> 0.140.1-107.1.1.1
- fix for handling API URLs with non-root path
* Wed Jul 17 2013 Miroslav Suchý <msuchy@redhat.com> 0.140.1-107.1.1
- add one number to release so we can distinguish from OpenSuse v-r
  (msuchy@redhat.com)
- rebase to 0.140.1 (msuchy@redhat.com)
* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.132.4-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild
* Fri Jul 20 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.132.4-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild
* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.132.4-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild
* Tue Jun 21 2011 Jerome Soyer <saispo@gmail.com> - 0.132.4-1
- Update to 0.132.4
* Thu Jun  9 2011 Jerome Soyer <saispo@gmail.com> - 0.132.1-2
- Fix non-arch dependent shell script in /usr/lib for multilib
* Wed Jun  8 2011 Jerome Soyer <saispo@gmail.com> - 0.132.1-1
- Update to 0.132.1
- Fix tab/space in SPEC file
- Add comment and command for tarball creation
- Fix libdir-macro-in-noarch-package
* Wed Jun  8 2011 Jerome Soyer <saispo@gmail.com> - 0.132.0-1
- Initial build
